@@ -150,11 +150,21 @@ disk_display_new (t_disk *disk, t_mounter *mounter)
         dd->hbox = gtk_hbox_new (FALSE, 10);
         gtk_container_add (GTK_CONTAINER(dd->menu_item), dd->hbox);
 
-        if (g_str_has_prefix(disk->device, "/dev/mapper/"))
-            format_LVM_name (disk->device, &formatted_diskname);
+        if (mounter->trim_devicenames)
+        {
+          if (g_str_has_prefix(disk->device, "/dev/mapper/"))
+            format_LVM_name (disk->device_short, &formatted_diskname);
+          else
+            formatted_diskname = g_strdup(disk->device_short);
+        }
         else
+        {
+          if (g_str_has_prefix(disk->device, "/dev/mapper/"))
+            format_LVM_name (disk->device, &formatted_diskname);
+          else
             formatted_diskname = g_strdup(disk->device);
-
+        }
+        
         if (mounter->exclude_devicenames)
             dd->label_disk = gtk_label_new (disk->mount_point);
         else
@@ -276,7 +286,7 @@ mounter_data_new (t_mounter *mt)
     TRACE ("enters mounter_data_new");
 
     /* get static infos from /etc/fstab */
-    mt->pdisks = disks_new (mt->include_NFSs, &(mt->showed_fstab_dialog));
+    mt->pdisks = disks_new (mt->include_NFSs, &(mt->showed_fstab_dialog), mt->trim_devicename_count);
 
     /* remove unwanted file systems from list */
     if (mt->exclude_FSs) {
@@ -293,7 +303,7 @@ mounter_data_new (t_mounter *mt)
     }
 
     /* get dynamic infos on mounts */
-    disks_refresh (mt->pdisks, array /* =GPtrArray *excluded_FSs */ );
+    disks_refresh (mt->pdisks, array /* =GPtrArray *excluded_FSs */ , mt->trim_devicename_count);
 
     /* menu with menu_item */
     mt->menu = gtk_menu_new ();
@@ -389,6 +399,13 @@ mounter_read_config (XfcePanelPlugin *plugin, t_mounter *mt)
         mt->include_NFSs = atoi(xfce_rc_read_entry(rc, "include_NFSs", NULL));
     else
         mt->include_NFSs = xfce_rc_read_bool_entry(rc, "include_networked_filesystems", FALSE);
+        
+    if (xfce_rc_has_entry(rc, "trim_devicenames"))
+        mt->trim_devicenames = xfce_rc_read_bool_entry(rc, "trim_devicenames", FALSE);
+
+    if (xfce_rc_has_entry(rc, "td_count"))
+        mt->trim_devicename_count = atoi(xfce_rc_read_entry(rc, "td_count", NULL));
+
 
     if (xfce_rc_has_entry(rc, "exclude_FSs"))
         mt->exclude_FSs = atoi(xfce_rc_read_entry(rc, "exclude_FSs", NULL));
@@ -415,7 +432,7 @@ static void
 mounter_write_config (XfcePanelPlugin *plugin, t_mounter *mt)
 {
     XfceRc *rc;
-    char *file;
+    char *file, tmp[4];
     TRACE ("enter write_config");
 
     if (!(file = xfce_panel_plugin_save_location (plugin, TRUE)))
@@ -437,6 +454,9 @@ mounter_write_config (XfcePanelPlugin *plugin, t_mounter *mt)
     xfce_rc_write_entry (rc, "icon", mt->icon);
     xfce_rc_write_bool_entry (rc, "show_message_dialog", mt->message_dialog);
     xfce_rc_write_bool_entry (rc, "include_networked_filesystems", mt->include_NFSs);
+    xfce_rc_write_bool_entry (rc, "trim_devicenames", mt->trim_devicenames);
+    snprintf(tmp, 4, "%d", mt->trim_devicename_count);
+    xfce_rc_write_entry (rc, "td_count", tmp);
     xfce_rc_write_bool_entry (rc, "exclude_selected_filesystems", mt->exclude_FSs);
     xfce_rc_write_bool_entry (rc, "exclude_devicenames_in_menu", mt->exclude_devicenames);
     xfce_rc_write_bool_entry (rc, "eject_cddrives", mt->eject_drives);
@@ -455,7 +475,7 @@ create_mounter_control (XfcePanelPlugin *plugin)
 
     mounter = g_new0(t_mounter,1);
 
-    /* default configuration values for when no configuration is found */
+    /* default configuration values if no configuration is found */
     mounter->icon = g_strdup(PACKAGE_DATA_DIR"/icons/hicolor/scalable/apps/xfce-mount.svg");
     mounter->mount_command = g_strdup(DEFAULT_MOUNT_COMMAND);
     mounter->umount_command = g_strdup(DEFAULT_UMOUNT_COMMAND);
@@ -463,6 +483,8 @@ create_mounter_control (XfcePanelPlugin *plugin)
     mounter->excluded_filesystems = g_strdup("");
     mounter->message_dialog = FALSE;
     mounter->include_NFSs = FALSE;
+    mounter->trim_devicenames = TRUE;
+    mounter->trim_devicename_count = 14;
     mounter->exclude_FSs = FALSE;
     mounter->eject_drives = FALSE;
     mounter->exclude_devicenames = FALSE;
@@ -550,6 +572,12 @@ mounter_apply_options (t_mounter_dialog *md)
 
     mt->exclude_devicenames = gtk_toggle_button_get_active
             (GTK_TOGGLE_BUTTON(md->show_exclude_devicenames));
+            
+    mt->trim_devicenames = gtk_toggle_button_get_active
+            (GTK_TOGGLE_BUTTON(md->show_trim_devicenames));
+            
+    mt->trim_devicename_count = gtk_spin_button_get_value_as_int
+            (GTK_SPIN_BUTTON(md->spin_trim_devicename_count));
 
     if (mt->include_NFSs!=incl_NFSs || mt->exclude_FSs!=excl_FSs
         || strlen(mt->excluded_filesystems)!=0) {
@@ -633,13 +661,27 @@ exlude_FSs_toggled (GtkWidget *widget, t_mounter_dialog *md)
 }
 
 
-/*static gboolean
+static gboolean
 exclude_devicenames_toggled (GtkWidget *widget, t_mounter_dialog *md)
 {
-
+    gboolean val;
+    
+    val = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+    gtk_widget_set_sensitive(gtk_widget_get_parent(GTK_WIDGET(md->show_trim_devicenames)), !val);
 
     return TRUE;
-}*/
+}
+
+static gboolean
+trim_devicenames_toggled (GtkWidget *widget, t_mounter_dialog *md)
+{
+    gboolean val;
+    
+    val = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+    gtk_widget_set_sensitive(GTK_WIDGET(md->spin_trim_devicename_count), val);
+
+    return TRUE;
+}
 
 static void
 mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
@@ -909,8 +951,41 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
     gtk_container_add (GTK_CONTAINER (_eventbox), md->show_exclude_devicenames );
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(md->show_exclude_devicenames),
                                 mt->exclude_devicenames);
-
-
+    g_signal_connect ( G_OBJECT(md->show_exclude_devicenames), "toggled",
+        G_CALLBACK(exclude_devicenames_toggled), md);
+        
+    /* Trim device names */
+    _eventbox = gtk_event_box_new ();
+    gtk_box_pack_start (GTK_BOX (_vbox), GTK_WIDGET(_eventbox),
+                        FALSE, FALSE, 0);
+    gtk_widget_show (_eventbox);
+    gtk_tooltips_set_tip ( GTK_TOOLTIPS(tip), _eventbox,
+        _("Trim the device names to the number of characters specified in the spin button."),
+        NULL );
+    _hbox = gtk_hbox_new (FALSE, BORDER);
+    gtk_widget_show (_hbox);
+    gtk_container_add (GTK_CONTAINER (_eventbox), _hbox );
+    gtk_widget_set_sensitive(GTK_WIDGET(_hbox), !mt->exclude_devicenames);
+    md->show_trim_devicenames = gtk_check_button_new_with_mnemonic (
+                                _("Trim device names: ") );
+    gtk_widget_show (md->show_trim_devicenames);
+    gtk_box_pack_start (GTK_BOX (_hbox), GTK_WIDGET(md->show_trim_devicenames),
+                        FALSE, FALSE, 0);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(md->show_trim_devicenames),
+                                mt->trim_devicenames);
+    g_signal_connect ( G_OBJECT(md->show_trim_devicenames), "toggled",
+        G_CALLBACK(trim_devicenames_toggled), md);
+                    
+    _label = gtk_label_new(_(" characters"));
+    gtk_widget_show (_label);
+    gtk_box_pack_end (GTK_BOX (_hbox), GTK_WIDGET(_label),
+                        FALSE, FALSE, 0);
+    md->spin_trim_devicename_count = gtk_spin_button_new_with_range (9.0, 99.0, 1.0);
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(md->spin_trim_devicename_count), (double) mt->trim_devicename_count);
+    gtk_widget_show (md->spin_trim_devicename_count);
+    gtk_box_pack_end (GTK_BOX (_hbox), GTK_WIDGET(md->spin_trim_devicename_count),
+                        FALSE, FALSE, 0);
+    
 
         /* Exclude file systems  */
     _eventbox = gtk_event_box_new ();
@@ -961,7 +1036,7 @@ mounter_show_about(XfcePanelPlugin *plugin, t_mounter *mt)
    GdkPixbuf *icon;
    const gchar *auth[] = { "Jean-Baptiste Dulong",
                            "Fabian Nowak <timystery@arcor.de>",
-                           "Landry Breuil <landry at xfce.org>", NULL };
+                           "Landry Breuil <landry@xfce.org>", NULL };
    icon = xfce_panel_pixbuf_from_source("drive-harddisk", NULL, 32);
    gtk_show_about_dialog(NULL,
       "logo", icon,
@@ -972,6 +1047,7 @@ mounter_show_about(XfcePanelPlugin *plugin, t_mounter *mt)
       "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-mount-plugin",
       "copyright", _("Copyright (c) 2005-2012\n"),
       "authors", auth, NULL);
+  // TODO: add translators.
 
    if(icon)
       g_object_unref(G_OBJECT(icon));
